@@ -9,7 +9,7 @@
 //#include <sharing-transfer.h>
 //#include <sharing-entry.h>
 #include <sharing-plugin-interface.h>
-
+#include <sharing-service-option.h>
 #include <dlfcn.h>
 
 #include <libxml/tree.h>
@@ -24,19 +24,26 @@
 
 #define MODULE_INIT "msa_module_init"
 #define XPATH_GET_ALBUM "//TransitData/Content/Response/Params/array[@name='albumList']"
+#define XPATH_GET_PARAMS "//TransitData/Content/Response/Params"
 #define ALBUM_PROP_ID "id"
 #define XPATH_GET_ERRCODE "//TransitData/Content/Response[@class='systemMessages']/Params/string[@name='code']"
 
 #define LIB_PATH "libvkontakte.so"
 
+#define DRIVER_ID "vkontakte"
+#define NODE_SETTINGS "settings"
+
 void* handle;
 struct msa_module* driver_module;
 gint (* driver_init)(struct msa_module*);
 
-gboolean libvk_init(gchar* proxy_host, gint proxy_port);
-void libvk_set_settings(gchar *login, gchar *password, gchar *autoupdate, gchar *active);
-SharingPluginInterfaceSendResult libvk_getAlbums(GList** list_album);
+gboolean libvk_init(gchar* proxy_host, gint proxy_port, gchar* account_name);
+void libvk_set_settings(gchar *params);
+gboolean libvk_get_settings(SharingAccount* account);
+SharingPluginInterfaceSendResult libvk_getAlbums(GSList** list_album);
 void libvk_uploadPhoto(gchar *aid, gchar *file, gchar *file_name);
 static xmlNodePtr xpath_get_node(char* path, xmlDocPtr doc);
 static xmlXPathObject* xpath(gchar* req, xmlDocPtr doc);
 
+gboolean libvk_testConnection();
+
