@@ -180,10 +180,9 @@ sharing_plugin_interface_update_options (SharingAccount *account,
     if((libvk_getAlbums(&list_albums)) != SHARING_SEND_SUCCESS)
     {
         g_print("%s:%d:%s: error: can't get album id", __FILE__, __LINE__, __FUNCTION__);
-        return FALSE;
-    }
-
-    ret = sharing_account_set_option_values(account, "album", list_albums);
+        ret = FALSE;
+    } else
+        ret = sharing_account_set_option_values(account, "album", list_albums);
 
     /* Callback */
     void (*fp) (SharingPluginInterfaceUpdateOptionsResult, gpointer);
